==> ejc-wzxt-impl-3.0.0-20200927.090253-9-sources.jar: com/ejianc/business/wzxt/bean/CheckEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_check")
public class CheckEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同主键
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_tenant_id")
    private java.lang.Long supplierTenantId; // 供应商租户ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @TableField(value="check_date")
    private java.util.Date checkDate; // 验收日期
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 验收人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 验收人名称
    @TableField(value="check_address")
    private java.lang.String checkAddress; // 验收地点
    @TableField(value="check_type")
    private java.lang.String checkType; // 业务类型
    @TableField(value="check_state")
    private java.lang.Integer checkState; // 验收状态（1-保存态，0-暂存态）
    @TableField(value="is_requirement")
    private java.lang.String isRequirement; // 是否满足质量要求0-是，1-否
    @TableField(value="is_standard")
    private java.lang.String isStandard; // 是否满足合同要求0-是，1-否
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="license_plate")
    private java.lang.String licensePlate; // 车牌号
    @TableField(value="use_state")
    private java.lang.Integer useState; // 引用状态（0-未引用，1-已引用）

    // 验收明细子表
    @TableField(exist = false)
    @SubEntity(serviceName="checkDetailService",pidName = "checkId")
    private List<CheckDetailEntity> detailList = new ArrayList<>();

    public List<CheckDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CheckDetailEntity> detailList) {
        this.detailList = detailList;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 发货主键
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商租户ID
     */
    public java.lang.Long getSupplierTenantId() {
        return supplierTenantId;
    }

    /**
     * 供应商租户ID
     */
    public void setSupplierTenantId(java.lang.Long supplierTenantId) {
        this.supplierTenantId = supplierTenantId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public java.lang.String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(java.lang.String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public java.lang.String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(java.lang.String checkType) {
        this.checkType = checkType;
    }
    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public java.lang.Integer getCheckState() {
        return checkState;
    }

    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public void setCheckState(java.lang.Integer checkState) {
        this.checkState = checkState;
    }
    /**
     * 是否满足质量要求0-是，1-否
     */
    public java.lang.String getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-是，1-否
     */
    public void setIsRequirement(java.lang.String isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public java.lang.String getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(java.lang.String isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public java.lang.String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(java.lang.String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }

}

==> ejc-wzxt-impl-3.0.0-20200928.082849-11-sources.jar: com/ejianc/business/wzxt/bean/CheckEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_check")
public class CheckEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同主键
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_tenant_id")
    private java.lang.Long supplierTenantId; // 供应商租户ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @TableField(value="check_date")
    private java.util.Date checkDate; // 验收日期
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 验收人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 验收人名称
    @TableField(value="check_address")
    private java.lang.String checkAddress; // 验收地点
    @TableField(value="check_type")
    private java.lang.String checkType; // 业务类型
    @TableField(value="check_state")
    private java.lang.Integer checkState; // 验收状态（1-保存态，0-暂存态，3-已验收）
    @TableField(value="is_requirement")
    private java.lang.String isRequirement; // 是否满足质量要求0-是，1-否
    @TableField(value="is_standard")
    private java.lang.String isStandard; // 是否满足合同要求0-是，1-否
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="license_plate")
    private java.lang.String licensePlate; // 车牌号
    @TableField(value="use_state")
    private java.lang.Integer useState; // 引用状态（0-未引用，1-已引用）

    // 验收明细子表
    @TableField(exist = false)
    @SubEntity(serviceName="checkDetailService",pidName = "checkId")
    private List<CheckDetailEntity> detailList = new ArrayList<>();

    public List<CheckDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CheckDetailEntity> detailList) {
        this.detailList = detailList;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 发货主键
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商租户ID
     */
    public java.lang.Long getSupplierTenantId() {
        return supplierTenantId;
    }

    /**
     * 供应商租户ID
     */
    public void setSupplierTenantId(java.lang.Long supplierTenantId) {
        this.supplierTenantId = supplierTenantId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public java.lang.String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(java.lang.String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public java.lang.String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(java.lang.String checkType) {
        this.checkType = checkType;
    }
    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public java.lang.Integer getCheckState() {
        return checkState;
    }

    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public void setCheckState(java.lang.Integer checkState) {
        this.checkState = checkState;
    }
    /**
     * 是否满足质量要求0-是，1-否
     */
    public java.lang.String getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-是，1-否
     */
    public void setIsRequirement(java.lang.String isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public java.lang.String getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(java.lang.String isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public java.lang.String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(java.lang.String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }

}
